@@ -4,6 +4,7 @@ import string
 import sys
 import typing
 from itertools import count
+from pathlib import Path
 
 import pytest
 import typing_extensions
@@ -12,13 +13,15 @@ version_re = re.compile(r"_py(\d)(\d)\.py$")
 pytest_plugins = ["pytester"]
 
 
-def pytest_ignore_collect(path, config):
-    match = version_re.search(path.basename)
+def pytest_ignore_collect(collection_path: Path, config: pytest.Config) -> bool:
+    match = version_re.search(collection_path.name)
     if match:
         version = tuple(int(x) for x in match.groups())
         if sys.version_info < version:
             return True
 
+    return False
+
 
 @pytest.fixture
 def sample_set() -> set:
